@@ -1,9 +1,9 @@
 import pgljs from '../pgljs/dist/index.js';
-import * as THREE from 'three';
-import { IDecodingTask, ITaskData, ITaskResult, IGeom } from './interfaces';
+import { IDecodingTask, ITaskData, ITaskResult } from './interfaces';
 
 let MAX_WORKER = 10;
 const workers: Map<Worker, IDecodingTask[]> = new Map();
+
 const getWorker = (): Worker => {
 
     const avg = Array.from(workers.values()).reduce((s, v) => s + v.length / workers.size, 0);
@@ -33,38 +33,7 @@ const getWorker = (): Worker => {
                     if (evt.data.error) {
                         reject({ error: evt.data.error, userData});
                     } else {
-                        let meshs: THREE.Mesh[] = evt.data.map((geom: IGeom) => {
-                            let mesh;
-                            const geometry = new THREE.BufferGeometry();
-                            geometry.setIndex(new THREE.BufferAttribute(new Uint32Array(geom.index), 1));
-                            geometry.setAttribute('position', new THREE.BufferAttribute(new Float32Array(geom.position), 3));
-                            const material = new THREE.MeshPhongMaterial({
-                                side: THREE.DoubleSide,
-                                shadowSide: THREE.BackSide,
-                                color: new THREE.Color(...geom.material.color),
-                                emissive: new THREE.Color(...geom.material.emission),
-                                specular: new THREE.Color(...geom.material.specular),
-                                shininess: geom.material.shininess * 100,
-                                transparent: geom.material.transparency > 0,
-                                opacity: 1 - geom.material.transparency,
-                                vertexColors: false
-                            });
-                            if (geom.isInstanced) {
-                                const instances = new Float32Array(geom.instances);
-                                mesh = new THREE.InstancedMesh(geometry, material, instances.length / 16);
-                                for (let i = 0; i < instances.length / 16; i++) {
-                                    mesh.setMatrixAt(i, (new THREE.Matrix4() as any).set(...instances.slice(i * 16, i * 16 + 16)));
-                                }
-                            } else {
-                                mesh = new THREE.Mesh(geometry, material);
-                            }
-                            geometry.computeVertexNormals();
-                            mesh.castShadow = true;
-                            mesh.receiveShadow = true;
-                            return mesh;
-                        });
-
-                        resolve({ results: meshs, userData });
+                        resolve({ results: evt.data, userData });
                     }
                 }
             }
@@ -101,21 +70,21 @@ const getWorker = (): Worker => {
 
 class Decoder {
 
-    decode(task: ITaskData, bucketID: string = ''): Promise<ITaskResult> {
+    decode(task: ITaskData, taskId: string = ''): Promise<ITaskResult> {
         const worker = getWorker();
         return new Promise((resolve, reject) => {
-            workers.get(worker).push({ bucketID, resolve, reject, ...task });
+            workers.get(worker).push({ taskId: taskId, resolve, reject, ...task });
             if ((worker as any).initialized) {
                 worker.postMessage(task.data);
             }
         });
     }
 
-    abort(bucketID: string) {
+    abort(taskId: string) {
         let tasks: IDecodingTask[] = [];
         for (const worker of workers.keys()) {
-            tasks = [...tasks, ...workers.get(worker).filter(task => task.bucketID === bucketID)];
-            workers.set(worker, workers.get(worker).filter(task => task.bucketID !== bucketID));
+            tasks = [...tasks, ...workers.get(worker).filter(task => task.taskId === taskId)];
+            workers.set(worker, workers.get(worker).filter(task => task.taskId !== taskId));
         }
         // reject in order
         tasks.sort((a, b) => a.userData.no - b.userData.no)
